==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/mi-NZ/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Nga taonga kua tohaina ki: ingoa',
    'bulk_update_warn'	=> 'Kei te tata koe ki te whakatika i nga taonga o: kaiwhakamahi kaiwhakamahi_count. Kia mohio koe kaore e taea e koe te whakarereke i a koe ake huanga kaiwhakamahi me te whakamahi i tenei puka, me te whakarereke i to hoa ake.',
    'bulk_update_help'	=> 'Ko tenei puka ka taea e koe te whakahou i nga kaiwhakamahi maha i te wa kotahi. Whakakiia nga mara e hiahia ana koe ki te huri. Ko nga mara katoa e mahue ana ka noho tonu.',
    'current_assets'    => 'Ko nga taonga kei te tirotirohia i tenei wa ki tenei kaiwhakamahi',
    'clone'             => 'Kaiwhakamahi Tino',
    'contact_user'      => 'Whakapā: ingoa',
    'edit'              => 'Whakatika Kaiwhakamahi',
    'filetype_info'     => 'Ko nga piriti kua whakaaetia he png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, me te rar.',
    'history_user'      => 'Hītori mō: ingoa',
    'info'				=> 'Mōhiohio',
    'restore_user'		=> 'Pāwhiri ki konei kia whakahokia mai.',
    'last_login'        => 'Whakauru Whakamutunga',
    'ldap_config_text'  => 'Ka taea te kitea nga tautuhinga whirihora LDAP Kaiwhakahaere> Tautuhinga. Ko te (tahua) kua tohua te tauwāhi kua tohua mo nga kaiwhakamahi katoa kua kawemai.',
    'print_assigned'    => 'Print All Assigned',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Pūmanawa Kua tirotirohia ki: ingoa',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Tirohia te Kaiwhakamahi: ingoa',
    'usercsv'           => 'Kōnae CSV',
    'two_factor_admin_optin_help' => 'Ko to tautuhinga kaiwhakahaere o toianei kei te whakarite i te whakatinanatanga o te whakamotuhēhēnga-rua.',
    'two_factor_enrolled' => 'Kua whakauruhia te Pūrere 2FA',
    'two_factor_active'   => '2FA Mahi',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/mi-NZ/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Nga taonga kua tohaina ki: ingoa',
    'bulk_update_warn'	=> 'Kei te tata koe ki te whakatika i nga taonga o: kaiwhakamahi kaiwhakamahi_count. Kia mohio koe kaore e taea e koe te whakarereke i a koe ake huanga kaiwhakamahi me te whakamahi i tenei puka, me te whakarereke i to hoa ake.',
    'bulk_update_help'	=> 'Ko tenei puka ka taea e koe te whakahou i nga kaiwhakamahi maha i te wa kotahi. Whakakiia nga mara e hiahia ana koe ki te huri. Ko nga mara katoa e mahue ana ka noho tonu.',
    'current_assets'    => 'Ko nga taonga kei te tirotirohia i tenei wa ki tenei kaiwhakamahi',
    'clone'             => 'Kaiwhakamahi Tino',
    'contact_user'      => 'Whakapā: ingoa',
    'edit'              => 'Whakatika Kaiwhakamahi',
    'filetype_info'     => 'Ko nga piriti kua whakaaetia he png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, me te rar.',
    'history_user'      => 'Hītori mō: ingoa',
    'info'				=> 'Mōhiohio',
    'restore_user'		=> 'Pāwhiri ki konei kia whakahokia mai.',
    'last_login'        => 'Whakauru Whakamutunga',
    'ldap_config_text'  => 'Ka taea te kitea nga tautuhinga whirihora LDAP Kaiwhakahaere> Tautuhinga. Ko te (tahua) kua tohua te tauwāhi kua tohua mo nga kaiwhakamahi katoa kua kawemai.',
    'print_assigned'    => 'Print All Assigned',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Pūmanawa Kua tirotirohia ki: ingoa',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Tirohia te Kaiwhakamahi: ingoa',
    'usercsv'           => 'Kōnae CSV',
    'two_factor_admin_optin_help' => 'Ko to tautuhinga kaiwhakahaere o toianei kei te whakarite i te whakatinanatanga o te whakamotuhēhēnga-rua.',
    'two_factor_enrolled' => 'Kua whakauruhia te Pūrere 2FA',
    'two_factor_active'   => '2FA Mahi',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];
